SpongePaddingValue

Trait SpongePaddingValue 

pub trait SpongePaddingValue: Copy {
    const PAD_ZERO: Self;
    const PAD_ONE: Self;
}
Values that can act as sponge lanes for delimiter padding.

This is used by symmetric sponge adapters that need canonical 0 and 1 symbols while supporting both field/ring-based lanes and u64-based Keccak lanes behind one API.

Required Associated Constants

const PAD_ZERO: Self

The empty-lane value.

const PAD_ONE: Self

The delimiter value injected after the final absorbed element.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SpongePaddingValue for u64

Source

const PAD_ZERO: Self = 0

Source

const PAD_ONE: Self = 1

Source

impl<const N: usize> SpongePaddingValue for [u64; N]

Source

const PAD_ZERO: Self

Source

const PAD_ONE: Self

Implementors

Source

impl<T: PrimeCharacteristicRing + Copy> SpongePaddingValue for T

Source

const PAD_ZERO: Self = Self::ZERO

Source

const PAD_ONE: Self = Self::ONE